# 25 "src/kernel_internals/parsing/logic_lexer.mll"
 

  open Logic_parser
  open Lexing

  type state = Normal | Test

  let state_stack = Stack.create ()

  let () = Stack.push Normal state_stack

  let get_state () = try Stack.top state_stack with Stack.Empty -> Normal

  let pop_state () = try ignore (Stack.pop state_stack) with Stack.Empty -> ()

  exception Error of (int * int) * string

  let loc lexbuf = (lexeme_start lexbuf, lexeme_end lexbuf)

  let lex_error lexbuf s =
    raise (Error (loc lexbuf, "lexical error, " ^ s))

  let find_utf8 =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [ Utf8_logic.forall, FORALL;
        Utf8_logic.exists, EXISTS;
        Utf8_logic.eq, EQ;
        Utf8_logic.neq, NE;
        Utf8_logic.le, LE;
        Utf8_logic.ge, GE;
        Utf8_logic.implies,IMPLIES;
        Utf8_logic.iff, IFF;
        Utf8_logic.conj, AND;
        Utf8_logic.disj, OR;
        Utf8_logic.neg, NOT;
        Utf8_logic.x_or, HATHAT;
        Utf8_logic.minus, MINUS;
        Utf8_logic.boolean, BOOLEAN;
        Utf8_logic.integer, INTEGER;
        Utf8_logic.real, REAL;
        Utf8_logic.inset, IN;
        Utf8_logic.pi, PI;
      ];

    fun s -> try Hashtbl.find h s
    with Not_found -> IDENTIFIER s

  let all_digits s =
    let is_digit =
      function
      | '0'..'9' | 'a'..'f' | 'A'..'F' -> ()
      | _ -> raise Exit
    in
    try String.iter is_digit s; true with Exit -> false

  let is_ucn s =
    if String.length s <= 2 || s.[0] <> '\\' then false else begin
      match s.[1] with
      | 'U' -> String.length s = 10 && all_digits (String.sub s 2 8)
      | 'u' -> String.length s = 6 && all_digits (String.sub s 2 4)
      | _ -> false
    end

  let int_of_digit chr =
    match chr with
    | '0'..'9' -> (Char.code chr) - (Char.code '0')
    | 'a'..'f' -> (Char.code chr) - (Char.code 'a') + 10
    | 'A'..'F' -> (Char.code chr) - (Char.code 'A') + 10
    | _ -> assert false

  (* assumes is_ucn s *)
  let unicode_char s =
    let code = ref 0 in
    let add_digit c = code := 16 * !code + int_of_digit c in
    String.iter add_digit (String.sub s 2 (String.length s - 2));
    let c = Utf8_logic.from_unichar !code in
    find_utf8 c

  let identifier, is_acsl_keyword =
    let all_kw = Hashtbl.create 37 in
    let type_kw = Hashtbl.create 3 in
    List.iter
      (fun (i,t) -> Hashtbl.add all_kw i t;)
      [
        "admit", (fun _ -> ADMIT);
        "allocates", (fun _ -> ALLOCATES);
        "assert", (fun _ -> ASSERT);
        "assigns", (fun _ -> ASSIGNS);
        "assumes", (fun _ -> ASSUMES);
        "at", (fun _ -> EXT_AT);
        (* ACSL extension for external spec file *)
        "axiom", (fun _ -> AXIOM);
        "axiomatic", (fun _ -> AXIOMATIC);
        "behavior", (fun _ -> BEHAVIOR);
        "behaviors", (fun _ -> BEHAVIORS);
        "_Bool", (fun _ -> BOOL);
        "breaks", (fun _ -> BREAKS);
        "case", (fun _ -> CASE);
        "char", (fun _ -> CHAR);
        "check", (fun _ -> CHECK);
        "complete", (fun _ -> COMPLETE);
        "const", (fun _ -> CONST);
        "continues", (fun _ -> CONTINUES);
        "contract", (fun _ -> CONTRACT);
        (* ACSL extension for external spec file *)
        "decreases", (fun _ -> DECREASES);
        "disjoint", (fun _ -> DISJOINT);
        "double", (fun _ -> DOUBLE);
        "else", (fun _ -> ELSE);
        "ensures", (fun _ -> ENSURES);
        "enum", (fun _ -> ENUM);
        "exits", (fun _ -> EXITS);
        "frees", (fun _ -> FREES);
        "function", (fun _ -> FUNCTION);
        (* ACSL extension for external spec file *)
        "float", (fun _ -> FLOAT);
        "for", (fun _ -> FOR);
        "global", (fun _ -> GLOBAL);
        "if", (fun _ -> IF);
	"impact", (fun _ -> IMPACT);
	"inductive", (fun _ -> INDUCTIVE);
	"include", (fun _ -> INCLUDE);
        (* ACSL extension for external spec file *)
        "int", (fun _ -> INT);
        "invariant", (fun _ -> INVARIANT);
        "label", (fun _ -> LABEL);
        "lemma", (fun _ -> LEMMA);
        "let", (fun _ -> EXT_LET);
        (* ACSL extension for external spec file *)
        "logic", (fun _ -> LOGIC);
        "long", (fun _ -> LONG);
        "loop", (fun _ -> LOOP);
        "model", (fun _ -> MODEL);
        (* ACSL extension for model fields *)
        "module", (fun _ -> MODULE);
        (* ACSL extension for external spec file *)
        "pragma", (fun _ -> PRAGMA);
        "predicate", (fun _ -> PREDICATE);
        "reads", (fun _ -> READS);
        "requires", (fun _ -> REQUIRES);
        "returns", (fun _ -> RETURNS);
        "short", (fun _ -> SHORT);
        "signed", (fun _ -> SIGNED);
        "sizeof", (fun _ -> SIZEOF);
        "slice", (fun _ -> SLICE);
        "struct", (fun _ -> STRUCT);
        "terminates", (fun _ -> TERMINATES);
        "type", (fun _ -> TYPE);
        "union", (fun _ -> UNION);
        "unsigned", (fun _ -> UNSIGNED);
        "variant", (fun _ -> VARIANT);
        "void", (fun _ -> VOID);
        "volatile", (fun _ -> VOLATILE);
        "writes", (fun _ -> WRITES);
        "__FC_FILENAME__",
        (fun loc ->
           let filename =
             Filepath.(Normalized.to_pretty_string (fst loc).pos_path)
           in
           STRING_LITERAL (false,filename));
      ];
    List.iter (fun (x, y) -> Hashtbl.add type_kw x y)
      ["integer", INTEGER; "real", REAL; "boolean", BOOLEAN; ];
    (fun s loc ->
      try
        (Hashtbl.find all_kw s)
        loc
      with Not_found ->
        let res =
          match Logic_env.extension_category s with
          | exception Not_found -> None
          | Cil_types.Ext_contract -> Some (EXT_CONTRACT s)
          | Cil_types.Ext_global ->
            begin
              match Logic_env.is_extension_block s with
              | false -> Some (EXT_GLOBAL s)
              | true -> Some (EXT_GLOBAL_BLOCK s)
            end
          | Cil_types.Ext_code_annot _ -> Some (EXT_CODE_ANNOT s)
        in
        match res with
        | None ->
          if Logic_env.typename_status s then TYPENAME s
          else
            (try
               Hashtbl.find type_kw s
             with Not_found -> IDENTIFIER s)
        | Some lex -> lex
    ),
    (fun s -> Hashtbl.mem all_kw s || Hashtbl.mem type_kw s)

  let bs_identifier =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [
        "\\allocation", ALLOCATION;
        "\\allocable", ALLOCABLE;
        "\\automatic", AUTOMATIC;
        "\\at", AT;
        "\\base_addr", BASE_ADDR;
        "\\block_length", BLOCK_LENGTH;
        "\\dynamic", DYNAMIC;
        "\\empty", EMPTY;
        "\\exists", EXISTS;
        "\\false", FALSE;
        "\\forall", FORALL;
        "\\freeable", FREEABLE;
        "\\fresh", FRESH;
        "\\from", FROM;
        "\\ghost", BSGHOST;
        "\\initialized", INITIALIZED;
        "\\dangling", DANGLING;
        "\\in", IN;
        "\\inter", INTER;
        "\\lambda", LAMBDA;
        "\\let", LET;
        "\\nothing", NOTHING;
        "\\null", NULL;
        "\\offset", OFFSET;
        "\\old", OLD;
        "\\pi", PI;
        "\\register", REGISTER;
        "\\result", RESULT;
        "\\separated", SEPARATED;
        "\\static", STATIC;
        "\\true", TRUE;
        "\\type", BSTYPE;
        "\\typeof", TYPEOF;
        "\\unallocated", UNALLOCATED;
        "\\union", BSUNION;
        "\\object_pointer", OBJECT_POINTER;
        "\\valid", VALID;
        "\\valid_read", VALID_READ;
        "\\valid_index", VALID_INDEX;
        "\\valid_range", VALID_RANGE;
        "\\valid_function", VALID_FUNCTION;
        "\\with", WITH;
      ];
    fun lexbuf ->
      let s = lexeme lexbuf in
      if is_ucn s then unicode_char s else begin
        try Hashtbl.find h s with Not_found ->
          if Logic_env.typename_status s then TYPENAME s
          else IDENTIFIER s
      end

  (* Update lexer buffer. *)
  let update_line_pos lexbuf line =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <-
      { pos with
	Lexing.pos_lnum = line;
	Lexing.pos_bol = pos.Lexing.pos_cnum;
      }

  let update_file_pos lexbuf file =
   let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <- { pos with Lexing.pos_fname = file }

  let accept_c_comments_into_acsl_spec = ref false

  let hack_merge_tokens current next =
    match (current,next) with
    | CHECK, REQUIRES -> true, CHECK_REQUIRES
    | CHECK, ENSURES -> true, CHECK_ENSURES
    | CHECK, EXITS -> true, CHECK_EXITS
    | CHECK, RETURNS -> true, CHECK_RETURNS
    | CHECK, BREAKS -> true, CHECK_BREAKS
    | CHECK, CONTINUES -> true, CHECK_CONTINUES
    | CHECK, LOOP -> true, CHECK_LOOP
    | CHECK, INVARIANT -> true, CHECK_INVARIANT
    | CHECK, LEMMA -> true, CHECK_LEMMA
    | ADMIT, REQUIRES -> true, ADMIT_REQUIRES
    | ADMIT, ENSURES -> true, ADMIT_ENSURES
    | ADMIT, EXITS -> true, ADMIT_EXITS
    | ADMIT, RETURNS -> true, ADMIT_RETURNS
    | ADMIT, BREAKS -> true, ADMIT_BREAKS
    | ADMIT, CONTINUES -> true, ADMIT_CONTINUES
    | ADMIT, LOOP -> true, ADMIT_LOOP
    | ADMIT, INVARIANT -> true, ADMIT_INVARIANT
    | ADMIT, LEMMA -> true, ADMIT_LEMMA
    | _ -> false, current

  let type_to_string = function
    | TYPENAME s -> s
    | REAL -> "real"
    | BOOLEAN -> "boolean"
    | INTEGER -> "integer"
    | _ -> assert false

  let check_ext_plugin source plugin tok =
    match tok with
    | IDENTIFIER s ->
      if Plugin.is_present plugin then
        Kernel.warning ~once:true ~wkey:Kernel.wkey_extension_unknown ~source
          "Unregistered extension '%s' for plug-in %s" s plugin
      else
        Kernel.warning ~once:true ~wkey:Kernel.wkey_plugin_not_loaded ~source
          "Ignored extensions for unloaded plug-in %s" plugin;
      IDENTIFIER_EXT s
    | EXT_CODE_ANNOT s
    | EXT_GLOBAL s
    | EXT_GLOBAL_BLOCK s
    | EXT_CONTRACT s ->
      let plugin_from = Logic_env.extension_from s in
      if plugin_from = plugin && plugin = "kernel" then
        Kernel.abort ~source
          "Extension '%s' from frama-c's kernel should not be used with the syntax \
          \\kernel::%s" s s;
      if plugin_from <> plugin then
        Kernel.abort ~source
          "Extension '%s' is from %s and not %s" s plugin_from plugin;
      tok
    | _ ->
      Kernel.abort ~source
        "Type token \'%s\' received instead of extension identifier"
        (type_to_string tok)

# 322 "src/kernel_internals/parsing/logic_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\189\255\190\255\000\000\196\255\133\000\198\255\199\255\
    \200\255\201\255\197\000\209\255\211\255\166\000\218\255\203\000\
    \225\255\226\255\228\255\229\255\201\000\170\000\226\000\220\000\
    \223\000\205\000\237\255\001\001\223\000\004\001\252\000\034\001\
    \107\001\196\001\254\001\238\000\239\000\254\255\028\001\250\255\
    \089\001\252\255\253\255\216\255\251\255\073\002\229\000\131\002\
    \206\002\063\003\002\003\091\001\003\003\241\255\238\255\092\001\
    \030\003\059\003\246\000\071\003\240\000\141\003\164\003\223\003\
    \109\003\037\004\029\001\005\004\075\004\108\004\140\004\196\003\
    \240\255\150\004\179\004\211\004\221\004\240\004\017\005\049\005\
    \059\005\030\001\032\001\033\001\078\005\088\005\239\255\110\005\
    \120\005\149\005\159\005\188\005\198\005\227\005\244\000\239\005\
    \012\006\022\006\051\006\220\255\230\000\236\255\193\255\250\000\
    \249\000\249\000\235\255\250\000\233\255\227\255\251\000\234\255\
    \232\255\194\255\231\255\202\255\223\255\214\255\192\255\205\255\
    \195\255\231\000\251\255\252\255\084\006\253\255\075\001\157\006\
    \180\006\188\001\254\255\110\006\251\255\209\000\100\006\254\255\
    \255\255\205\000\216\000\252\255\135\001\252\255\133\003\254\255\
    \255\255\253\255\168\003\087\004\088\004\133\001\253\255\254\255\
    \255\255\001\003\252\255\253\255\015\001\255\255\254\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\064\000\255\255\058\000\255\255\255\255\
    \255\255\255\255\048\000\255\255\255\255\042\000\255\255\031\000\
    \255\255\255\255\255\255\255\255\025\000\043\000\040\000\036\000\
    \047\000\052\000\255\255\066\000\033\000\066\000\012\000\012\000\
    \008\000\008\000\066\000\038\000\045\000\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\007\000\255\255\255\255\
    \006\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \015\000\255\255\013\000\011\000\255\255\255\255\255\255\009\000\
    \255\255\255\255\009\000\255\255\255\255\255\255\015\000\255\255\
    \255\255\015\000\255\255\015\000\255\255\255\255\255\255\015\000\
    \255\255\010\000\010\000\011\000\015\000\255\255\255\255\255\255\
    \015\000\255\255\015\000\255\255\015\000\255\255\034\000\015\000\
    \255\255\015\000\255\255\255\255\051\000\255\255\255\255\255\255\
    \049\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\004\000\255\255\001\000\255\255\
    \000\000\001\000\255\255\255\255\255\255\004\000\002\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\003\000\255\255\
    \255\255\255\255\255\255\255\255\002\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\003\000\255\255\255\255";
  Lexing.lex_default =
   "\003\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\049\000\255\255\052\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \040\000\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\049\000\052\000\052\000\052\000\000\000\000\000\049\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\000\000\000\000\255\255\
    \255\255\255\255\000\000\255\255\000\000\000\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\122\000\000\000\000\000\255\255\000\000\255\255\255\255\
    \255\255\255\255\000\000\132\000\000\000\255\255\255\255\000\000\
    \000\000\255\255\255\255\000\000\141\000\000\000\146\000\000\000\
    \000\000\000\000\146\000\146\000\146\000\150\000\000\000\000\000\
    \000\000\154\000\000\000\000\000\255\255\000\000\000\000";
  Lexing.lex_trans =
   "\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\038\000\037\000\001\000\038\000\038\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \038\000\020\000\027\000\026\000\019\000\011\000\022\000\029\000\
    \009\000\008\000\035\000\014\000\018\000\023\000\028\000\036\000\
    \031\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\015\000\016\000\024\000\025\000\010\000\017\000\
    \038\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\033\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\005\000\034\000\004\000\013\000\032\000\
    \001\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\007\000\021\000\006\000\012\000\001\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\001\000\
    \002\000\120\000\119\000\118\000\117\000\116\000\115\000\113\000\
    \112\000\110\000\100\000\255\255\103\000\094\000\255\255\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\039\000\109\000\102\000\104\000\044\000\040\000\047\000\
    \081\000\081\000\099\000\054\000\101\000\038\000\114\000\107\000\
    \038\000\038\000\056\000\255\255\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\105\000\106\000\
    \108\000\111\000\137\000\138\000\038\000\139\000\158\000\000\000\
    \000\000\057\000\058\000\124\000\000\000\000\000\000\000\000\000\
    \058\000\000\000\000\000\058\000\043\000\000\000\081\000\081\000\
    \056\000\058\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\038\000\055\000\000\000\000\000\
    \051\000\057\000\058\000\042\000\060\000\255\255\255\255\057\000\
    \058\000\066\000\082\000\058\000\082\000\083\000\058\000\000\000\
    \000\000\058\000\066\000\082\000\000\000\082\000\083\000\058\000\
    \000\000\000\000\061\000\129\000\129\000\129\000\129\000\129\000\
    \129\000\129\000\129\000\000\000\060\000\000\000\000\000\057\000\
    \000\000\066\000\082\000\000\000\082\000\083\000\058\000\152\000\
    \143\000\144\000\066\000\082\000\143\000\082\000\083\000\058\000\
    \000\000\000\000\061\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\000\000\000\000\143\000\
    \000\000\142\000\000\000\000\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\000\000\
    \000\000\000\000\032\000\000\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\049\000\123\000\
    \000\000\000\000\000\000\050\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\255\255\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\000\000\
    \000\000\000\000\000\000\032\000\000\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\041\000\000\000\255\255\255\255\045\000\000\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\046\000\000\000\151\000\000\000\255\255\
    \000\000\000\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\000\000\000\000\000\000\000\000\
    \045\000\000\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\000\000\000\000\
    \000\000\000\000\048\000\000\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \000\000\000\000\000\000\157\000\255\255\255\255\000\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\255\255\053\000\156\000\000\000\048\000\000\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\255\255\000\000\000\000\086\000\000\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\051\000\051\000\
    \000\000\054\000\072\000\087\000\072\000\000\000\085\000\000\000\
    \085\000\000\000\072\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\056\000\000\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\000\000\072\000\087\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\000\000\057\000\000\000\255\255\000\000\
    \000\000\255\255\000\000\083\000\000\000\000\000\000\000\000\000\
    \076\000\000\000\076\000\055\000\083\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\145\000\
    \000\000\000\000\000\000\000\000\057\000\000\000\000\000\000\000\
    \000\000\255\255\000\000\083\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\062\000\083\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\000\000\
    \000\000\000\000\145\000\000\000\000\000\000\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\000\000\000\000\
    \000\000\147\000\000\000\000\000\000\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\000\000\000\000\000\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\000\000\000\000\
    \000\000\155\000\255\255\255\255\147\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\000\000\000\000\065\000\000\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\000\000\000\000\
    \000\000\000\000\000\000\066\000\000\000\000\000\000\000\064\000\
    \074\000\000\000\074\000\000\000\066\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\255\255\
    \063\000\063\000\063\000\063\000\063\000\063\000\000\000\000\000\
    \000\000\000\000\000\000\066\000\000\000\000\000\000\000\064\000\
    \000\000\000\000\000\000\000\000\066\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\000\000\
    \255\255\255\255\000\000\255\255\255\255\000\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\067\000\000\000\000\000\
    \000\000\148\000\145\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\255\255\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\000\000\000\000\000\000\067\000\000\000\071\000\
    \000\000\071\000\000\000\069\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\000\000\000\000\
    \255\255\000\000\000\000\000\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\000\000\147\000\147\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\069\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \072\000\000\000\072\000\000\000\000\000\000\000\000\000\000\000\
    \072\000\000\000\072\000\000\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\000\000\000\000\000\000\
    \072\000\000\000\072\000\000\000\000\000\000\000\000\000\000\000\
    \072\000\000\000\072\000\000\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\072\000\
    \000\000\072\000\000\000\000\000\000\000\000\000\000\000\072\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\077\000\077\000\077\000\077\000\077\000\077\000\072\000\
    \000\000\072\000\000\000\000\000\080\000\000\000\080\000\072\000\
    \078\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\077\000\077\000\077\000\077\000\077\000\077\000\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \078\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\072\000\000\000\072\000\
    \000\000\000\000\000\000\000\000\000\000\072\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\072\000\000\000\072\000\072\000\000\000\072\000\
    \000\000\093\000\072\000\093\000\000\000\072\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\072\000\000\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\000\000\072\000\089\000\072\000\000\000\
    \091\000\000\000\091\000\000\000\072\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\000\000\000\000\000\000\072\000\089\000\072\000\000\000\
    \000\000\000\000\000\000\072\000\072\000\072\000\000\000\000\000\
    \000\000\000\000\000\000\072\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \000\000\000\000\000\000\072\000\000\000\072\000\000\000\000\000\
    \000\000\000\000\072\000\072\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\000\000\000\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\000\000\072\000\000\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\072\000\096\000\072\000\000\000\098\000\
    \000\000\098\000\000\000\072\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \000\000\000\000\000\000\072\000\096\000\072\000\000\000\000\000\
    \000\000\000\000\072\000\072\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\125\000\135\000\
    \136\000\000\000\072\000\125\000\072\000\000\000\000\000\000\000\
    \000\000\000\000\072\000\000\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\126\000\000\000\000\000\135\000\000\000\
    \000\000\000\000\000\000\125\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \000\000\000\000\000\000\000\000\127\000\000\000\000\000\000\000\
    \125\000\000\000\000\000\000\000\000\000\125\000\125\000\000\000\
    \000\000\000\000\125\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\125\000\000\000\000\000\000\000\125\000\000\000\
    \125\000\000\000\125\000\000\000\127\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\128\000\000\000\
    \000\000\000\000\133\000\000\000\000\000\000\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\000\000\000\000\000\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\005\000\010\000\010\000\013\000\015\000\020\000\021\000\
    \022\000\023\000\025\000\027\000\024\000\028\000\029\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\036\000\023\000\024\000\024\000\035\000\036\000\046\000\
    \060\000\060\000\094\000\027\000\100\000\038\000\021\000\103\000\
    \038\000\038\000\030\000\029\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\104\000\105\000\
    \107\000\110\000\133\000\137\000\038\000\138\000\156\000\255\255\
    \255\255\030\000\058\000\121\000\255\255\255\255\255\255\255\255\
    \030\000\255\255\255\255\058\000\035\000\255\255\081\000\081\000\
    \031\000\030\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\038\000\027\000\255\255\255\255\
    \029\000\030\000\058\000\040\000\031\000\051\000\055\000\031\000\
    \030\000\066\000\081\000\058\000\082\000\083\000\031\000\255\255\
    \255\255\030\000\066\000\081\000\255\255\082\000\083\000\031\000\
    \255\255\255\255\031\000\126\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\255\255\031\000\255\255\255\255\031\000\
    \255\255\066\000\081\000\255\255\082\000\083\000\031\000\149\000\
    \140\000\140\000\066\000\081\000\140\000\082\000\083\000\031\000\
    \255\255\255\255\031\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\255\255\255\255\140\000\
    \255\255\140\000\255\255\255\255\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\255\255\255\255\
    \255\255\255\255\032\000\255\255\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\033\000\121\000\
    \255\255\255\255\255\255\033\000\129\000\129\000\129\000\129\000\
    \129\000\129\000\129\000\129\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\255\255\255\255\
    \255\255\027\000\255\255\255\255\029\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\255\255\
    \255\255\255\255\255\255\033\000\255\255\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\040\000\255\255\051\000\055\000\034\000\255\255\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\255\255\149\000\255\255\140\000\
    \255\255\255\255\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\255\255\255\255\255\255\255\255\
    \045\000\255\255\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\255\255\255\255\
    \255\255\255\255\047\000\255\255\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \255\255\255\255\255\255\153\000\050\000\052\000\255\255\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\050\000\052\000\153\000\255\255\048\000\255\255\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\049\000\255\255\255\255\056\000\255\255\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\050\000\052\000\
    \255\255\049\000\056\000\056\000\056\000\255\255\057\000\255\255\
    \057\000\255\255\056\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\059\000\255\255\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\255\255\056\000\056\000\056\000\255\255\255\255\255\255\
    \255\255\255\255\056\000\255\255\059\000\255\255\142\000\255\255\
    \255\255\142\000\255\255\059\000\255\255\255\255\255\255\255\255\
    \064\000\255\255\064\000\049\000\059\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\142\000\
    \255\255\255\255\255\255\255\255\059\000\255\255\255\255\255\255\
    \255\255\146\000\255\255\059\000\146\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\061\000\059\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\255\255\
    \255\255\255\255\146\000\255\255\255\255\255\255\061\000\061\000\
    \061\000\061\000\061\000\061\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\255\255\255\255\
    \255\255\142\000\255\255\255\255\255\255\062\000\062\000\062\000\
    \062\000\062\000\062\000\255\255\255\255\255\255\061\000\061\000\
    \061\000\061\000\061\000\061\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\255\255\255\255\
    \255\255\153\000\050\000\052\000\146\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\255\255\255\255\063\000\255\255\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \063\000\063\000\063\000\063\000\063\000\063\000\255\255\255\255\
    \255\255\255\255\255\255\063\000\255\255\255\255\255\255\063\000\
    \067\000\255\255\067\000\255\255\063\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\049\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\255\255\255\255\
    \255\255\255\255\255\255\063\000\255\255\255\255\255\255\063\000\
    \255\255\255\255\255\255\255\255\063\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\255\255\
    \147\000\148\000\255\255\147\000\148\000\255\255\065\000\065\000\
    \065\000\065\000\065\000\065\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\065\000\255\255\255\255\
    \255\255\147\000\148\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\142\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\255\255\255\255\255\255\065\000\255\255\069\000\
    \255\255\069\000\255\255\068\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\255\255\255\255\
    \146\000\255\255\255\255\255\255\068\000\068\000\068\000\068\000\
    \068\000\068\000\255\255\147\000\148\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\068\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \070\000\255\255\070\000\255\255\255\255\255\255\255\255\255\255\
    \070\000\255\255\073\000\255\255\073\000\255\255\255\255\255\255\
    \255\255\255\255\073\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\255\255\255\255\255\255\
    \070\000\255\255\070\000\255\255\255\255\255\255\255\255\255\255\
    \070\000\255\255\073\000\255\255\073\000\255\255\255\255\255\255\
    \255\255\255\255\073\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\075\000\
    \255\255\075\000\255\255\255\255\255\255\255\255\255\255\075\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\077\000\077\000\077\000\077\000\077\000\077\000\075\000\
    \255\255\075\000\255\255\255\255\078\000\255\255\078\000\075\000\
    \077\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\077\000\077\000\077\000\077\000\077\000\077\000\147\000\
    \148\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \077\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\080\000\080\000\080\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\079\000\255\255\079\000\
    \255\255\255\255\255\255\255\255\255\255\079\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \085\000\085\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\084\000\255\255\084\000\079\000\255\255\079\000\
    \255\255\087\000\084\000\087\000\255\255\079\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\084\000\255\255\084\000\255\255\255\255\255\255\
    \255\255\255\255\084\000\255\255\088\000\088\000\088\000\255\255\
    \089\000\255\255\089\000\255\255\088\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\255\255\255\255\255\255\088\000\088\000\088\000\255\255\
    \255\255\255\255\255\255\090\000\088\000\090\000\255\255\255\255\
    \255\255\255\255\255\255\090\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \255\255\255\255\255\255\090\000\255\255\090\000\255\255\255\255\
    \255\255\255\255\092\000\090\000\092\000\255\255\255\255\255\255\
    \255\255\255\255\092\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\255\255\255\255\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\255\255\092\000\255\255\092\000\255\255\255\255\255\255\
    \255\255\255\255\092\000\095\000\095\000\095\000\255\255\096\000\
    \255\255\096\000\255\255\095\000\096\000\096\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \255\255\255\255\255\255\095\000\095\000\095\000\255\255\255\255\
    \255\255\255\255\097\000\095\000\097\000\255\255\255\255\255\255\
    \255\255\255\255\097\000\098\000\098\000\098\000\098\000\098\000\
    \098\000\098\000\098\000\098\000\098\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\124\000\131\000\
    \131\000\255\255\097\000\124\000\097\000\255\255\255\255\255\255\
    \255\255\255\255\097\000\255\255\124\000\124\000\124\000\124\000\
    \124\000\124\000\124\000\124\000\255\255\255\255\131\000\255\255\
    \255\255\255\255\255\255\124\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \255\255\255\255\255\255\255\255\124\000\255\255\255\255\255\255\
    \124\000\255\255\255\255\255\255\255\255\124\000\124\000\255\255\
    \255\255\255\255\124\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\124\000\255\255\255\255\255\255\124\000\255\255\
    \124\000\255\255\124\000\255\255\124\000\127\000\127\000\127\000\
    \127\000\127\000\127\000\127\000\127\000\127\000\127\000\255\255\
    \255\255\255\255\131\000\255\255\255\255\255\255\127\000\127\000\
    \127\000\127\000\127\000\127\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\128\000\128\000\128\000\
    \128\000\128\000\128\000\255\255\255\255\255\255\127\000\127\000\
    \127\000\127\000\127\000\127\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\128\000\128\000\128\000\
    \128\000\128\000\128\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\131\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\075\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\013\000\016\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\001\000\001\000\000\000\000\000\000\000\004\000\
    \004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\000\000\000\000\000\000\000\000\007\000\
    \000\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\000\000\000\000\
    \000\000\000\000\007\000\000\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_check_code =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\033\000\255\255\255\255\255\255\000\000\
    \033\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\255\255\255\255\255\255\255\255\034\000\
    \255\255\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\255\255\255\255\
    \255\255\255\255\045\000\255\255\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_code =
   "\255\001\255\255\002\255\255\003\255\255\000\003\255\000\002\255\
    \000\001\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 4 (-1); __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 371 "src/kernel_internals/parsing/logic_lexer.mll"
           ( token lexbuf )
# 1044 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 372 "src/kernel_internals/parsing/logic_lexer.mll"
         ( Lexing.new_line lexbuf; token lexbuf )
# 1049 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 373 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( Lexing.new_line lexbuf; token lexbuf )
# 1054 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 374 "src/kernel_internals/parsing/logic_lexer.mll"
                     ( token lexbuf )
# 1059 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 375 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "unexpected block-comment closing" )
# 1064 "src/kernel_internals/parsing/logic_lexer.ml"

  | 5 ->
# 376 "src/kernel_internals/parsing/logic_lexer.mll"
         ( if !accept_c_comments_into_acsl_spec
           then comment lexbuf
           else lex_error lexbuf "unexpected block-comment opening"
         )
# 1072 "src/kernel_internals/parsing/logic_lexer.ml"

  | 6 ->
let
# 380 "src/kernel_internals/parsing/logic_lexer.mll"
                         plugin
# 1078 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 1) lexbuf.Lexing.lex_mem.(0)
and
# 380 "src/kernel_internals/parsing/logic_lexer.mll"
                                                      name
# 1083 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_mem.(0) + 2) lexbuf.Lexing.lex_curr_pos in
# 380 "src/kernel_internals/parsing/logic_lexer.mll"
                                                            (
     let loc = Lexing.(lexeme_start_p lexbuf, lexeme_end_p lexbuf) in
     let cabsloc = Cil_datatype.Location.of_lexing_loc loc in
     let tok = identifier name cabsloc in
     check_ext_plugin (fst cabsloc) plugin tok
     )
# 1092 "src/kernel_internals/parsing/logic_lexer.ml"

  | 7 ->
# 386 "src/kernel_internals/parsing/logic_lexer.mll"
                     ( bs_identifier lexbuf )
# 1097 "src/kernel_internals/parsing/logic_lexer.ml"

  | 8 ->
# 387 "src/kernel_internals/parsing/logic_lexer.mll"
                      (
      let loc = Lexing.(lexeme_start_p lexbuf, lexeme_end_p lexbuf) in
      let cabsloc = Cil_datatype.Location.of_lexing_loc loc in
      let s = lexeme lexbuf in
      let curr_tok = identifier s cabsloc in
      if curr_tok = CHECK || curr_tok = ADMIT then begin
        let next_tok =
          token { lexbuf with refill_buff = lexbuf.refill_buff }
        in
        let (eat_next, tok) = hack_merge_tokens curr_tok next_tok in
        if eat_next then ignore (token lexbuf);
        tok
      end else curr_tok
    )
# 1115 "src/kernel_internals/parsing/logic_lexer.ml"

  | 9 ->
# 402 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1120 "src/kernel_internals/parsing/logic_lexer.ml"

  | 10 ->
# 403 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1125 "src/kernel_internals/parsing/logic_lexer.ml"

  | 11 ->
# 404 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1130 "src/kernel_internals/parsing/logic_lexer.ml"

  | 12 ->
# 405 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1135 "src/kernel_internals/parsing/logic_lexer.ml"

  | 13 ->
# 406 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1140 "src/kernel_internals/parsing/logic_lexer.ml"

  | 14 ->
let
# 407 "src/kernel_internals/parsing/logic_lexer.mll"
                 prelude
# 1146 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 407 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                   content
# 1151 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 408 "src/kernel_internals/parsing/logic_lexer.mll"
      (
        let b = Buffer.create 5 in
        Buffer.add_string b prelude;
        let lbf = Lexing.from_string content in
        INT_CONSTANT (chr b lbf ^ "'")
      )
# 1160 "src/kernel_internals/parsing/logic_lexer.ml"

  | 15 ->
# 421 "src/kernel_internals/parsing/logic_lexer.mll"
      ( FLOAT_CONSTANT (lexeme lexbuf) )
# 1165 "src/kernel_internals/parsing/logic_lexer.ml"

  | 16 ->
let
# 424 "src/kernel_internals/parsing/logic_lexer.mll"
            n
# 1171 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 424 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( lexbuf.lex_curr_pos <- lexbuf.lex_curr_pos - 2;
                              INT_CONSTANT n )
# 1176 "src/kernel_internals/parsing/logic_lexer.ml"

  | 17 ->
let
# 427 "src/kernel_internals/parsing/logic_lexer.mll"
                prelude
# 1182 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 427 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                content
# 1187 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 428 "src/kernel_internals/parsing/logic_lexer.mll"
      ( STRING_LITERAL (prelude.[0] = 'L',content) )
# 1191 "src/kernel_internals/parsing/logic_lexer.ml"

  | 18 ->
# 429 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( hash lexbuf )
# 1196 "src/kernel_internals/parsing/logic_lexer.ml"

  | 19 ->
# 430 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IMPLIES )
# 1201 "src/kernel_internals/parsing/logic_lexer.ml"

  | 20 ->
# 431 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IFF )
# 1206 "src/kernel_internals/parsing/logic_lexer.ml"

  | 21 ->
# 432 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIMPLIES )
# 1211 "src/kernel_internals/parsing/logic_lexer.ml"

  | 22 ->
# 433 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIFF )
# 1216 "src/kernel_internals/parsing/logic_lexer.ml"

  | 23 ->
# 434 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AND )
# 1221 "src/kernel_internals/parsing/logic_lexer.ml"

  | 24 ->
# 435 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( OR )
# 1226 "src/kernel_internals/parsing/logic_lexer.ml"

  | 25 ->
# 436 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NOT )
# 1231 "src/kernel_internals/parsing/logic_lexer.ml"

  | 26 ->
# 437 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOLLAR )
# 1236 "src/kernel_internals/parsing/logic_lexer.ml"

  | 27 ->
# 438 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COMMA )
# 1241 "src/kernel_internals/parsing/logic_lexer.ml"

  | 28 ->
# 439 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( ARROW )
# 1246 "src/kernel_internals/parsing/logic_lexer.ml"

  | 29 ->
# 440 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Test state_stack; QUESTION )
# 1251 "src/kernel_internals/parsing/logic_lexer.ml"

  | 30 ->
# 441 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SEMICOLON )
# 1256 "src/kernel_internals/parsing/logic_lexer.ml"

  | 31 ->
# 442 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( match get_state() with
                                  Normal  -> COLON
                                | Test -> pop_state(); COLON2
                            )
# 1264 "src/kernel_internals/parsing/logic_lexer.ml"

  | 32 ->
# 446 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONCOLON )
# 1269 "src/kernel_internals/parsing/logic_lexer.ml"

  | 33 ->
# 447 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOT )
# 1274 "src/kernel_internals/parsing/logic_lexer.ml"

  | 34 ->
# 448 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOT )
# 1279 "src/kernel_internals/parsing/logic_lexer.ml"

  | 35 ->
# 449 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOTDOT )
# 1284 "src/kernel_internals/parsing/logic_lexer.ml"

  | 36 ->
# 450 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( MINUS )
# 1289 "src/kernel_internals/parsing/logic_lexer.ml"

  | 37 ->
# 451 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PLUS )
# 1294 "src/kernel_internals/parsing/logic_lexer.ml"

  | 38 ->
# 452 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STAR )
# 1299 "src/kernel_internals/parsing/logic_lexer.ml"

  | 39 ->
# 453 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STARHAT )
# 1304 "src/kernel_internals/parsing/logic_lexer.ml"

  | 40 ->
# 454 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AMP )
# 1309 "src/kernel_internals/parsing/logic_lexer.ml"

  | 41 ->
# 455 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HATHAT )
# 1314 "src/kernel_internals/parsing/logic_lexer.ml"

  | 42 ->
# 456 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HAT )
# 1319 "src/kernel_internals/parsing/logic_lexer.ml"

  | 43 ->
# 457 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PIPE )
# 1324 "src/kernel_internals/parsing/logic_lexer.ml"

  | 44 ->
# 458 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( TILDE )
# 1329 "src/kernel_internals/parsing/logic_lexer.ml"

  | 45 ->
# 459 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SLASH )
# 1334 "src/kernel_internals/parsing/logic_lexer.ml"

  | 46 ->
# 460 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PERCENT )
# 1339 "src/kernel_internals/parsing/logic_lexer.ml"

  | 47 ->
# 461 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LT )
# 1344 "src/kernel_internals/parsing/logic_lexer.ml"

  | 48 ->
# 462 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GT )
# 1349 "src/kernel_internals/parsing/logic_lexer.ml"

  | 49 ->
# 463 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LE )
# 1354 "src/kernel_internals/parsing/logic_lexer.ml"

  | 50 ->
# 464 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GE )
# 1359 "src/kernel_internals/parsing/logic_lexer.ml"

  | 51 ->
# 465 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQ )
# 1364 "src/kernel_internals/parsing/logic_lexer.ml"

  | 52 ->
# 466 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQUAL )
# 1369 "src/kernel_internals/parsing/logic_lexer.ml"

  | 53 ->
# 467 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NE )
# 1374 "src/kernel_internals/parsing/logic_lexer.ml"

  | 54 ->
# 468 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LPAR )
# 1379 "src/kernel_internals/parsing/logic_lexer.ml"

  | 55 ->
# 469 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RPAR )
# 1384 "src/kernel_internals/parsing/logic_lexer.ml"

  | 56 ->
# 470 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LBRACE )
# 1389 "src/kernel_internals/parsing/logic_lexer.ml"

  | 57 ->
# 471 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RBRACE )
# 1394 "src/kernel_internals/parsing/logic_lexer.ml"

  | 58 ->
# 472 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUARE )
# 1399 "src/kernel_internals/parsing/logic_lexer.ml"

  | 59 ->
# 473 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUARE )
# 1404 "src/kernel_internals/parsing/logic_lexer.ml"

  | 60 ->
# 474 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUAREPIPE )
# 1409 "src/kernel_internals/parsing/logic_lexer.ml"

  | 61 ->
# 475 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUAREPIPE )
# 1414 "src/kernel_internals/parsing/logic_lexer.ml"

  | 62 ->
# 476 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTLT )
# 1419 "src/kernel_internals/parsing/logic_lexer.ml"

  | 63 ->
# 477 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GTGT )
# 1424 "src/kernel_internals/parsing/logic_lexer.ml"

  | 64 ->
let
# 478 "src/kernel_internals/parsing/logic_lexer.mll"
                 c
# 1430 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 478 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( find_utf8 c )
# 1434 "src/kernel_internals/parsing/logic_lexer.ml"

  | 65 ->
# 479 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EOF )
# 1439 "src/kernel_internals/parsing/logic_lexer.ml"

  | 66 ->
# 480 "src/kernel_internals/parsing/logic_lexer.mll"
        ( lex_error lexbuf ("illegal character " ^ lexeme lexbuf) )
# 1444 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and chr buffer lexbuf =
   __ocaml_lex_chr_rec buffer lexbuf 121
and __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 484 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 2 (String.length s - 2) in
        let rec add_one_char s =
          let l = String.length s in
          if l = 0 then ()
          else
          let h = int_of_digit s.[0] in
          let c,s =
            if l = 1 then (h,"")
            else
              (16*h + int_of_digit s.[1],
               String.sub s 2 (String.length s - 2))
          in
          Buffer.add_char buffer (Char.chr c); add_one_char s
        in add_one_char real_s; chr buffer lexbuf
      )
# 1471 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 501 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 1 (String.length s - 1) in
        let rec value i s =
          if s = "" then i
          else value (8*i+int_of_digit s.[0])
            (String.sub s 1 (String.length s -1))
        in let c = value 0 real_s in
        Buffer.add_char buffer (Char.chr c); chr buffer lexbuf
      )
# 1484 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 511 "src/kernel_internals/parsing/logic_lexer.mll"
      ( Buffer.add_char buffer
          (match (lexeme lexbuf).[1] with
               'a' -> '\007'
             | 'b' -> '\b'
             | 'f' -> '\012'
             | 'n' -> '\n'
             | 'r' -> '\r'
             | 't' -> '\t'
             | 'v' -> '\011' (* no '\v' in OCaml 😞 *)
             | '\'' -> '\''
             | '"' -> '"'
             | '?' -> '?'
             | '\\' -> '\\'
             | _ -> (* escape regex does not allow anything else *) assert false
          ); chr buffer lexbuf)
# 1503 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 526 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Buffer.contents buffer )
# 1508 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 527 "src/kernel_internals/parsing/logic_lexer.mll"
       ( Buffer.add_string buffer (lexeme lexbuf); chr buffer lexbuf )
# 1513 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state

and hash lexbuf =
   __ocaml_lex_hash_rec lexbuf 131
and __ocaml_lex_hash_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 530 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Lexing.new_line lexbuf; token lexbuf)
# 1525 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 531 "src/kernel_internals/parsing/logic_lexer.mll"
             ( hash lexbuf)
# 1530 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 532 "src/kernel_internals/parsing/logic_lexer.mll"
              ( (* We are seeing a line number. This is the number for the
                   * next line *)
                 let s = Lexing.lexeme lexbuf in
                 let lineno =
                   try
                     int_of_string s
                   with Failure _ ->
                     (* the int is too big. *)
                     Kernel.warning
                       ~source:(Cil_datatype.Position.of_lexing_pos lexbuf.lex_start_p)
                       "Bad line number in preprocessed file: %s"  s;
                     (-1)
                 in
                 update_line_pos lexbuf (lineno - 1);
                  (* A file name may follow *)
		  file lexbuf )
# 1550 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 548 "src/kernel_internals/parsing/logic_lexer.mll"
                ( hash lexbuf )
# 1555 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 549 "src/kernel_internals/parsing/logic_lexer.mll"
            ( endline lexbuf)
# 1560 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_hash_rec lexbuf __ocaml_lex_state

and file lexbuf =
   __ocaml_lex_file_rec lexbuf 140
and __ocaml_lex_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 552 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( Lexing.new_line lexbuf; token lexbuf)
# 1572 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 553 "src/kernel_internals/parsing/logic_lexer.mll"
                  ( file lexbuf)
# 1577 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 554 "src/kernel_internals/parsing/logic_lexer.mll"
                                        (
    let n = Lexing.lexeme lexbuf in
    let n1 = String.sub n 1
        ((String.length n) - 2) in
    let unescape = Str.regexp_string "\\\"" in
    let n1 = Str.global_replace unescape "\"" n1 in
    update_file_pos lexbuf n1;
    endline lexbuf
  )
# 1590 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 564 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1595 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_file_rec lexbuf __ocaml_lex_state

and endline lexbuf =
   __ocaml_lex_endline_rec lexbuf 149
and __ocaml_lex_endline_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 567 "src/kernel_internals/parsing/logic_lexer.mll"
                ( Lexing.new_line lexbuf; token lexbuf)
# 1607 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 568 "src/kernel_internals/parsing/logic_lexer.mll"
                                ( EOF )
# 1612 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 569 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1617 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_endline_rec lexbuf __ocaml_lex_state

and comment lexbuf =
   __ocaml_lex_comment_rec lexbuf 153
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 572 "src/kernel_internals/parsing/logic_lexer.mll"
         ( Lexing.new_line lexbuf; comment lexbuf)
# 1629 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 573 "src/kernel_internals/parsing/logic_lexer.mll"
         ( token lexbuf)
# 1634 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 574 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "non-terminating block-comment" )
# 1639 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 575 "src/kernel_internals/parsing/logic_lexer.mll"
         ( comment lexbuf)
# 1644 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

;;

# 577 "src/kernel_internals/parsing/logic_lexer.mll"
 
  (* When Ocaml 4.11+ becomes mandatory, we can probably replace this with
     Lexing.set_position. *)
  let set_initial_position dest_lexbuf src_pos =
    dest_lexbuf.Lexing.lex_curr_p <- src_pos;
    dest_lexbuf.lex_abs_pos <- src_pos.pos_cnum

  let parse_from_position f (pos, s : Filepath.position * string) =
    let output = Kernel.warning ~wkey:Kernel.wkey_annot_error
    in
    let lb = from_string s in
    set_initial_position lb (Cil_datatype.Position.to_lexing_pos pos);
    try
      let res = f token lb in
      Some (Cil_datatype.Position.of_lexing_pos lb.Lexing.lex_curr_p, res)
    with
      | Failure s -> (* raised by the lexer itself, through [f] *)
          output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "lexing error: %s" s; None
      | Parsing.Parse_error ->
        output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "unexpected token '%s'" (Lexing.lexeme lb);
        None
      | Error (_, m) -> output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "%s" m; None
      | Logic_utils.Not_well_formed (loc, m) ->
        output ~source:(fst loc) "%s" m;
        None
      | Logic_utils.Unknown_ext -> None
      | Log.FeatureRequest(source,_,msg) ->
        let source = Option.value ~default:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) source in
        output ~source "unimplemented ACSL feature: %s" msg; None
      | Log.AbortError _ as exn -> raise exn
      | exn ->
        Kernel.fatal ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "Unknown error (%s)"
          (Printexc.to_string exn)

  let lexpr = parse_from_position Logic_parser.lexpr_eof

  let annot = parse_from_position Logic_parser.annot

  let spec = parse_from_position Logic_parser.spec

  let ext_spec lexbuf = try
      accept_c_comments_into_acsl_spec := true ;
      let r = Logic_parser.ext_spec token lexbuf in
      accept_c_comments_into_acsl_spec := false ;
      r
    with exn ->
      accept_c_comments_into_acsl_spec := false ;
      raise exn

  type 'a parse = Filepath.position * string -> (Filepath.position * 'a) option

  let chr lexbuf =
    let buf = Buffer.create 16 in
    chr buf lexbuf

# 1707 "src/kernel_internals/parsing/logic_lexer.ml"
